==> iwrite-3.0.1.0.tar.gz: iwrite-3.0.1.0/src/item_property.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler 
*/
/*
Copyright (c) 2016, iwrite authors 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_property_h__

#include "item_common.h"
#include "database_field.h"
#include "mainw.h"

struct item_table_dialog
{
  GtkComboBoxText*                      m_query_comboboxtext;
  GtkComboBoxText*                      m_column_comboboxtext;
};

extern void
item_property_border_color_button_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

extern void
item_property_color_button_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

extern void
item_property_fill_color_button_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

extern void
item_property_font_button_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

extern void
item_property_comboboxtext_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

extern void
item_property_database_set_active(
  GtkComboBoxText*                      io_query_comboboxtext,
  GtkComboBoxText*                      io_column_comboboxtext,
  struct item_table const*const         i_table);

extern void
item_property_load_group(
  GtkComboBoxText*                      io_group_comboboxtext);

extern void
item_property_group_set_active(
  GtkComboBoxText*                      io_group_comboboxtext,
  char const*                           i_group);

extern void
item_property_load_query(
  GtkComboBoxText*                      io_query_comboboxtext);

#define __item_property_h__
#endif

==> iwrite-3.1.1.0.tar.gz: iwrite-3.1.1.0/src/item_property.h <==
/* 
vim:expandtab:softtabstop=2:tabstop=2:shiftwidth=2:nowrap:ruler 
*/
/*
Copyright (c) 2016, iwrite authors 
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions
are met:

1. Redistributions of source code must retain the above copyright notice,
this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
notice, this list of conditions and the following disclaimer in the
documentation and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
#ifndef __item_property_h__

#include "item_common.h"
#include "database_field.h"
#include "mainw.h"

struct item_table_dialog
{
  GtkComboBoxText*                      m_query_comboboxtext;
  GtkComboBoxText*                      m_column_comboboxtext;
};

extern void
item_property_border_color_button_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

extern void
item_property_color_button_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

extern void
item_property_fill_color_button_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

extern void
item_property_font_button_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

extern void
item_property_comboboxtext_cb(
  GtkWidget *                           i_widget,
  gpointer                              i_data);

/* _mjo TODO: use item_table_dialog as parameter */
extern void
item_property_database_set_active(
  GtkComboBoxText*                      io_query_comboboxtext,
  GtkComboBoxText*                      io_column_comboboxtext,
  struct item_table const*const         i_table);

extern void
item_property_load_query(
  GtkComboBoxText*                      io_query_comboboxtext);

#define __item_property_h__
#endif
